==> haskell-crypto-api-tests-0.3-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-HtKZ4SI19hv5USlDTms5Dx
key: crypto-api-tests-0.3-HtKZ4SI19hv5USlDTms5Dx
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 6736de84ecfd2c09016e0a9526ea93af
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-HtKZ4SI19hv5USlDTms5Dx
depends:
    HUnit-1.6.0.0-F7HqWS6YZw9Ctb1uJk5Q8g
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
    test-framework-hunit-0.3.0.2-57Gm80kqLWmbLecMiTYXD
    test-framework-quickcheck2-0.3.0.5-AoWmyD30fuP4q3JX6JnLoO
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-1oBW4QXXJm56a2YWuKyife
key: crypto-api-tests-0.3-1oBW4QXXJm56a2YWuKyife
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 487c1619f9d86f63c9ee0727bc85504a
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-1oBW4QXXJm56a2YWuKyife
depends:
    HUnit-1.6.0.0-GVISJ15whDC76D0YbOz5NN
    QuickCheck-2.13.2-8Fp36mG21e67uRy7VcQZNU base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
    test-framework-hunit-0.3.0.2-FN1OedIim482WfyJt6SYL
    test-framework-quickcheck2-0.3.0.5-BwX1zuPWJ372foyR6Aza19
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
